@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2007 Mathias Soeken <msoeken@tzi.de>
+  SPDX-FileCopyrightText: 2007 Mathias Soeken <msoeken@tzi.de>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "autochecktreewidget.h"
 
@@ -24,14 +11,8 @@ using namespace IncidenceEditorNG;
 class Q_DECL_HIDDEN AutoCheckTreeWidget::Private
 {
 public:
-    Private()
-        : mAutoCheckChildren(false)
-        , mAutoCheck(true)
-    {
-    }
-
-    bool mAutoCheckChildren;
-    bool mAutoCheck;
+    bool mAutoCheckChildren = false;
+    bool mAutoCheck = true;
 };
 //@endcond
 
@@ -57,7 +38,7 @@ QTreeWidgetItem *AutoCheckTreeWidget::itemByPath(const QStringList &path) const
     QStringList newPath = path;
     QTreeWidgetItem *item = nullptr;
 
-    while (newPath.count()) {
+    while (!newPath.isEmpty()) {
         item = findItem(item, newPath.takeFirst());
         if (!item) {
             return nullptr;
