@@ -1,43 +1,30 @@
 /*
-  Copyright (C) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencedialogfactory.h"
 #include "incidencedialog.h"
 #include "incidencedefaults.h"
 
-#include <KCalCore/Event>
-#include <KCalCore/Todo>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Todo>
 #include <Item>
 #include <Akonadi/Calendar/IncidenceChanger>
 
 using namespace IncidenceEditorNG;
-using namespace KCalCore;
+using namespace KCalendarCore;
 
-IncidenceDialog *IncidenceDialogFactory::create(bool needsSaving, KCalCore::IncidenceBase::IncidenceType type, Akonadi::IncidenceChanger *changer, QWidget *parent, Qt::WindowFlags flags)
+IncidenceDialog *IncidenceDialogFactory::create(bool needsSaving, KCalendarCore::IncidenceBase::IncidenceType type, Akonadi::IncidenceChanger *changer, QWidget *parent, Qt::WindowFlags flags)
 {
     switch (type) {
-    case KCalCore::IncidenceBase::TypeEvent: // Fall through
-    case KCalCore::IncidenceBase::TypeTodo:
-    case KCalCore::IncidenceBase::TypeJournal:
+    case KCalendarCore::IncidenceBase::TypeEvent: // Fall through
+    case KCalendarCore::IncidenceBase::TypeTodo:
+    case KCalendarCore::IncidenceBase::TypeJournal:
     {
-        IncidenceDialog *dialog = new IncidenceDialog(changer, parent, flags);
+        auto *dialog = new IncidenceDialog(changer, parent, flags);
 
         // needs to be save to akonadi?, apply button should be turned on if so.
         dialog->setInitiallyDirty(needsSaving /* mInitiallyDirty */);
@@ -49,8 +36,7 @@ IncidenceDialog *IncidenceDialogFactory::create(bool needsSaving, KCalCore::Inci
     }
 }
 
-IncidenceDialog *IncidenceDialogFactory::createTodoEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees,
-                                                          const QStringList &attachmentMimetypes, const QStringList &attachmentLabels, bool inlineAttachment,
+IncidenceDialog *IncidenceDialogFactory::createTodoEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees, const QStringList &attachmentMimetypes, const QStringList &attachmentLabels, bool inlineAttachment,
                                                           const Akonadi::Collection &defaultCollection, bool cleanupAttachmentTempFiles, QWidget *parent, Qt::WindowFlags flags)
 {
     IncidenceDefaults defaults
@@ -71,7 +57,7 @@ IncidenceDialog *IncidenceDialogFactory::createTodoEditor(const QString &summary
     item.setPayload(todo);
 
     IncidenceDialog *dialog = create(true,  /* no need for, we're not editing an existing to-do */
-                                     KCalCore::Incidence::TypeTodo,
+                                     KCalendarCore::Incidence::TypeTodo,
                                      nullptr,
                                      parent, flags);
     dialog->selectCollection(defaultCollection);
@@ -79,8 +65,7 @@ IncidenceDialog *IncidenceDialogFactory::createTodoEditor(const QString &summary
     return dialog;
 }
 
-IncidenceDialog *IncidenceDialogFactory::createEventEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees,
-                                                           const QStringList &attachmentMimetypes, const QStringList &attachmentLabels, bool inlineAttachment,
+IncidenceDialog *IncidenceDialogFactory::createEventEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees, const QStringList &attachmentMimetypes, const QStringList &attachmentLabels, bool inlineAttachment,
                                                            const Akonadi::Collection &defaultCollection, bool cleanupAttachmentTempFiles, QWidget *parent, Qt::WindowFlags flags)
 {
     IncidenceDefaults defaults
@@ -102,7 +87,7 @@ IncidenceDialog *IncidenceDialogFactory::createEventEditor(const QString &summar
 
     IncidenceDialog *dialog
         = create(false, // not needed for saving, as we're not editing an existing incidence
-                 KCalCore::Incidence::TypeEvent,
+                 KCalendarCore::Incidence::TypeEvent,
                  nullptr,
                  parent, flags);
 
